@@ -8,6 +8,8 @@ License: MIT
 from .cnn import DCNN
 from .utils import Processor_data, open_txt
 from mlearner.nlp import helpers
+from .cnn_advanced import DCNN_Advanced
+from .transformer import Transformer, Transformer_train
 
-__all__ = ["DCNN", "Processor_data", "open_txt", "helpers"]
-
+__all__ = ["DCNN", "Processor_data", "open_txt", "helpers", "DCNN_Advanced",
+            "Transformer", "Transformer_train"]
